% Calculating averaged spectra from NOAA hydrophone data
% Script modified by J. Haxel May 2015 to calculate the long-term time
% Secondly modified by S.Yun May 2020 for TNB and BI Data
% This code makes 'AveSpect.txt' and 'spectroinfo.mat' file
% system response = (preAmp + instResp)  is removed and energy values are
% normalized to dB re 1uPa @ 1m
% CF2 data - need to use haruInCF2.m instead of haruIn for all

% data info
clear all; close all;
  datadir = '/Volumes/AUH_TNB/Balleny/HC02/'; %working directory
  locname = 'BI15HC02'; % = Location(BI or TNB)+Year(yy)+Instrumentcode
  fnums = 1:1923;                   % Total Haru-file numbers to read
  sRate = 1000; %1000 Hz sample rate
  frameSize = 1000;         % for 1Hz resolution @ 1000Hz sample rate
  fdates = './timinginfo/file_dates-HC02-2015.txt'; %timing info
  !rm ./AvgSpect.txt
  fopen('AvgSpect.txt','w');
  %
% Parameters for time averaging and start/stop times
%period = 1/24;			% for hourly averaged
period = 1;  % Daily averaged
baseyear = 'auto';         % auto means get it from first day of data
zeroPad = 0;            % zero-pad the signal
nOverlap = 0;           % overlap data points

% remove the system gain from the spectra
% script to remove the pre-amp response and built in hi-pass of the FODH
% hydrophone at Challenger Deep
% SR is the system response including hydrophone sensitivity, pre-amp,
% hi-pass response and DC gain offset
% below is [freq gain] in dB - with gain setting and hydrophone hi-pass included

 switch locname
    case 'TNB16HC14'
        FODH = [1	11.11156146;
                2	24.30217162;
                5	35.6994742;
                10	40.65237522;
                20	43.15517772;
                50	44.30217162;
                100	44.93981398;
                200	46.35291086;
                300	47.84690311;
                380	49.17577763;
                390	49.36103583;
                400	48.98030633;
                410	46.54309025;
                420	42.56669274;
                430	38.19539829;
                440	34.50516133;
                450	30.72611745]; %[freq dB]

    case 'TNB17HC21'
        FODH = [1	14.07782801;
                2	27.353;
                5	38.725;
                10	43.976;
                20	46.732;
                50	48.121;
                100	49.056;
                200	51.247;
                300	53.405;
                380	55.065;
                390	55.208;
                400	55.351;
                410	55.553;
                420	55.809;
                430	55.799;
                440	54.554;
                450	51.335]; %[freq dB]

    case 'TNB17HC25'
        FODH = [1	15.11145925;
                2	28.034;
                5	39.461;
                10	44.464;
                20	46.9;
                50	48.119;
                100	49.043;
                200	51.324;
                300	53.476;
                380	55.103;
                390	55.262;
                400	55.505;
                410	55.714;
                420	55.234;
                430	52.817;
                440	48.816;
                450	44.397]; %[freq dB]

    case 'TNB18HC25'
        FODH = [1	15.11145925;
                2	28.034;
                5	39.461;
                10	44.464;
                20	46.9;
                50	48.119;
                100	49.043;
                200	51.324;
                300	53.476;
                380	55.103;
                390	55.262;
                400	55.505;
                410	55.714;
                420	55.234;
                430	52.817;
                440	48.816;
                450	44.397]; %[freq dB]

    case 'TNB18HC21'
        FODH = [1	14.07782801;
                2	27.353;
                5	38.725;
                10	43.976;
                20	46.732;
                50	48.121;
                100	49.056;
                200	51.247;
                300	53.405;
                380	55.065;
                390	55.208;
                400	55.351;
                410	55.553;
                420	55.809;
                430	55.799;
                440	54.554;
                450	51.335]; %[freq dB]  

    case 'BI15HC02'
        FODH = [1	19.06;
                2	28.15;
                5	36.73;
                10	42.75;
                20	47.15;
                50	50.46;
                100	52.02;
                200	54.59;
                380	58.5;
                390	58.04;
                400	55.54;
                410	51.16;
                420	46.52;
                430	42.34;
                500	32.76]; %[freq dB]

end


freq = [sRate/frameSize:sRate/frameSize:sRate/2];
%
% shape preserving piecewise cubic interpolation
int_resp = interp1(FODH(:,1),FODH(:,2),freq,'pchip');
%
% general system response(SR) = PreAmpGain + H-phone sensitivity
%
hphone_sens = -192; %dB re: 1uPa/V
SR = int_resp + hphone_sens; SR = SR';
%




%%%%%%%%%%%%%%%%%%%%%%%%% Configure data Grab %%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
hIndex = readHarufileDateIndex(fdates);
if (0)      %change for the old format of datafile
  fn0 = sprintf('%sdatafile.%03d', datadir, fnums(1));
  fn1 = sprintf('%sdatafile.%03d', datadir, fnums(end));
else
  fn0 = sprintf('%s%08d.DAT', datadir, fnums(1));
  fn1 = sprintf('%s%08d.DAT', datadir, fnums(end));
end
[dtv0,yr,jd,hr,mn,sc,sRate,t,y]=readCF2hdr(fn0,0);
[dtv1,yr,jd,hr,mn,sc,sRate,t,y]=readCF2hdr(fn1,0);
%
%
if (ischar(baseyear) && strcmp(baseyear, 'auto'))
  baseyear = sub(datevec(dtv0), 1);	% new dt encoding from soundIn
end
%
% Get start and stop times that include only whole intervals.
dt0 =  ceil(dtv0/period) * period;	% get start of first whole period
dt1 = floor(dtv1/period) * period;	% get end   of last  whole period
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%% Start the loop for calculating LTSpect %%%%%%%%%%%%%%
%
%if (1)
%  gram = zeros((frameSize+zeroPad)/2, round((dt1-dt0)/period));
  fRate = sRate / (frameSize - nOverlap);
%  printf('%d dots:', round((dt1-dt0)/period))
  for i = 1 : round((dt1-dt0)/period)
      fprintf(1,'.%s', iff(mod(i,60) == 0, char(10), ''));
    dt = dt0 + (i-1) * period;
% Do around 1 million samples at a time.
    t0 = dt;
    gSum = zeros((frameSize+zeroPad)/2, 1);
    ng = 0;
    while (t0 < dt + period)
      %t1 = min([dt+period double(t0+1e6/sRate/24/60/60)]); %for big AVG's
      t1 = dt + period;
      xt = haruSoundAtTime_CF2([t0 t1], hIndex, datadir);   %note - calling CF2 specific routine
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      xt_2 = xt{1}; xt_3 = xt_2(:,1); %extra step do to 2 channel data 
      x_mn = xt_3 - mean(xt_3);     %have to do this in 2 steps now because 2 channel data
      %
      x = (2.5/(2^16)).*x_mn;     % convert to Volts by (Voltrange/bitrange)- for 16bit 
      g = joespect_LTacoustic(x, frameSize, nOverlap, zeroPad, 'hanning', 1000);  %1000 for sample rate
      % last input on line above is sample rate
      if (nCols(g) == 0), break; end   % skip partial frame at end of day
      gSum = gSum + mean(g,2);   % sum up the energy - will divide later
      ng = ng + nCols(g);
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %t0 = t0 + nCols(g)/.9765624 / 24/60/60; %have to change this to make it run m10 hickup - 
      t0 = t0 + nCols(g) / double(fRate) / 24/60/60;  %/fRate return integer
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%    end
    grm = 10*log10(gSum);    %to convert power to dB
    sr = repmat(SR,1,length(grm(1,:)));
    grm = grm - sr;
    grm = grm';
    save('temp.txt', 'grm', '-ascii')
    !cat ./temp.txt >> ./AvgSpect.txt
    clear grm
    !rm temp.txt
%
  end
  %fprintf(i, '\n');
  end

 save spectroinfo locname dt0 dt1 period sRate

 movefile('AvgSpect.txt',datadir);
 movefile('spectroinfo.mat',datadir);
