% Calculating and plotting short spectrogram (Supplimentary Figure 3 in Yun
% et al, 2021)
% coded by Sukyoung Yun 2020.07

clear all; close all;

loc='BI';
year='2015';
Hid='HC02';
tag='W_';
locname = [loc, year(3:4), Hid];

Starttime = datenum([2015, 11, 19, 1, 10, 0]);
Endtime = datenum([2015, 11, 19, 1, 20, 0]);
%outputsrate = 1000; %sampling rate of output wave file

%dataname = ['Wav_',datestr(Starttime, 'yymmdd.HHMMSS'),'-',...
%    datestr(Endtime, 'yymmdd.HHMMSS'),'.txt'];
%Wavname = 'Wave.txt';
%K(:,1) = [0 : 0.001 : (Endtime-Starttime)*24*60*60-0.001]';

%% read data

datadir = ['/Volumes/AUH_TNB/Balleny/HC02/'];
%datadir = ['/Volumes/AUH_TNB/Balleny/' Hid '/'];
fdates = [datadir,'file_dates-', Hid,'-', year,'.txt']; 
hIndex = readHarufileDateIndex(fdates);
[xt sRate] = haruSoundAtTime_CF2([Starttime Endtime], hIndex, datadir);
x(:,1) = xt{1} - mean(xt{1});
clear hIndex xt

%save([datadir dataname], 'x', '-ascii');

%% plot spectrogram
%% Spectrogram parameters setting

%starttime = datenum(dataname(5:17),'yyyymmdd.HHMMSS'); % serial date number(days from Jan-1-0000) of the starting time, 
%savename = [datadir,dataname];
figname =[tag, locname,'_',datestr(Starttime, 'yymmdd.HHMMSS'),'_',datestr(Endtime, 'yymmdd.HHMMSS')]; 
winsize=1000;			% number of points of window size, time resolution
nOverlap = 500;           % overlap data points
nfft = 1000;       % frequency resolution = 1000Hz/nfft  

%% 3. System (instrumental frequency response) Response
% remove the system gain from the spectra
% script to remove the pre-amp response and built in hi-pass of the FODH
% below is [freq gain] in dB - with gain setting and hydrophone hi-pass included

switch locname
    case 'TNB16HC14'
        FODH = [1	11.11156146;
                2	24.30217162;
                5	35.6994742;
                10	40.65237522;
                20	43.15517772;
                50	44.30217162;
                100	44.93981398;
                200	46.35291086;
                300	47.84690311;
                380	49.17577763;
                390	49.36103583;
                400	48.98030633;
                410	46.54309025;
                420	42.56669274;
                430	38.19539829;
                440	34.50516133;
                450	30.72611745]; %[freq dB]
    case 'TNB17HC21'
        FODH = [1	14.07782801;
                2	27.353;
                5	38.725;
                10	43.976;
                20	46.732;
                50	48.121;
                100	49.056;
                200	51.247;
                300	53.405;
                380	55.065;
                390	55.208;
                400	55.351;
                410	55.553;
                420	55.809;
                430	55.799;
                440	54.554;
                450	51.335]; %[freq dB]
    case 'TNB17HC25'
        FODH = [1	15.11145925;
                2	28.034;
                5	39.461;
                10	44.464;
                20	46.9;
                50	48.119;
                100	49.043;
                200	51.324;
                300	53.476;
                380	55.103;
                390	55.262;
                400	55.505;
                410	55.714;
                420	55.234;
                430	52.817;
                440	48.816;
                450	44.397]; %[freq dB]
    case 'TNB18HC25'
        FODH = [1	15.11145925;
                2	28.034;
                5	39.461;
                10	44.464;
                20	46.9;
                50	48.119;
                100	49.043;
                200	51.324;
                300	53.476;
                380	55.103;
                390	55.262;
                400	55.505;
                410	55.714;
                420	55.234;
                430	52.817;
                440	48.816;
                450	44.397]; %[freq dB]
    case 'TNB18HC21'
        FODH = [1	14.07782801;
                2	27.353;
                5	38.725;
                10	43.976;
                20	46.732;
                50	48.121;
                100	49.056;
                200	51.247;
                300	53.405;
                380	55.065;
                390	55.208;
                400	55.351;
                410	55.553;
                420	55.809;
                430	55.799;
                440	54.554;
                450	51.335]; %[freq dB]       
    case 'BI15HC02'
        FODH = [1	19.06;
                2	28.15;
                5	36.73;
                10	42.75;
                20	47.15;
                50	50.46;
                100	52.02;
                200	54.59;
                380	58.5;
                390	58.04;
                400	55.54;
                410	51.16;
                420	46.52;
                430	42.34;
                500	32.76]; %[freq dB]
                Sname = 'BAL15';
     case 'BI15HC01'
        FODH = [1	15.06;
                2	20.15;
                5	32.73;
                10	38.75;
                20	41.15;
                50	47.46;
                100	50.02;
                200	53.59;
                380	58.5;
                390	58.04;
                400	55.54;
                410	51.16;
                420	46.52;
                430	42.34;
                500	32.76]; %[freq dB]
end

 
sRate=double(sRate);
freq = [0:sRate/nfft:sRate/2];
% shape preserving piecewise cubic interpolation
int_resp = interp1(FODH(:,1),FODH(:,2),freq,'pchip');
%
% general system response(SR) = PreAmpGain + H-phone sensitivity
%
hphone_sens = -192; %dB re: 1uPa/V
SR = int_resp + hphone_sens; SR = SR';
%

%% 4. Calculating Spectrogram
x = (2.5/(2^16)).*x;     % convert to Volts by (Voltrange/bitrange)- for 16bit 
[ysp,fsp,tsp,psp]=spectrogram(x,winsize,nOverlap,nfft,sRate); %calculating spectrogram
psp = 10*log10(psp);    %to convert power to dB
sr = repmat(SR,1,size(psp,2)); % extend system reponse matrix to the same time length of the psp
psp = psp - sr; %system response correction

%% 5. Plot spectrogram
%tspd = tsp./24/60/60 + Starttime;
surf(tsp,fsp,psp,'EdgeColor','none');  %surf plot
axis xy; colormap(jet); view(0,90) 
axis([tsp(1) tsp(end) 1 450]); 
%axis([tsp(1) tsp(end) 1 100]); 
%maxc=prctile(psp(:),97); % higest 97%
%minc=prctile(psp(:),38); % lowest 20%
%maxc=ceil(maxc/5)*5; minc=floor(minc/5)*5;
maxc = 85; minc=60;
caxis([minc maxc]); %axis limit
%ax = gca; % xy axis handle
%sizet = nCols(tsp);

set(gca,'LineWidth',2,'Tickdir','out');
set(gca,'fontsize',17);
ylabel(['Frequency [Hz]'],'fontsize',18);
xlabel(['Time [s]'],'fontsize',18);
%color bar setting
colorbar('location','eastoutside');
cbar_handle = findobj(gcf,'tag','Colorbar');
set(cbar_handle,'FontSize',17);
cbar_handle.Label.String = 'dB re 1 \muPa^{2}/Hz';

% write figure name on the top
title([Sname,datestr(Starttime, '   yyyy.mm.dd  HH:MM:SS')],'fontsize',22);

%% save mat file
%save([figname '.mat'],'Starttime','Endtime', 'loc', 'year', 'Hid', 'tag','x','tsp',...
%    'fsp','psp');


%% save figure
set(gcf,'PaperPosition',[0,0,25.4,12.7]); %set fig size
print(gcf,'-r300','-dtiff',[figname '.tiff']); %save plot as tiff format figure
saveas(gcf, [figname '.jpg']);
%saveas(gcf, [figname '.eps'], 'epsc');