function [x,sRate] = haruSoundAtTime_CF2(t, hIndex, dir)
%haruSoundAtTime	% Given start and stop times, get the sound signal
%
% x = haruSoundAtTime(t, hIndex, harufileDir)
%    Given a 2-column array t with columns of [startTime stopTime], an hIndex
%    as returned by readHarufileIndex, and a directory to find the Harufiles
%    in, return a cell column vector with the corresponding sound signals in 
%    it.  x has as many cells as there are rows in t.
%
%    If the Harufiles are in multiple directories named disk1/, disk2/, etc., 
%    harufileDir should be the directory containing the 'diskN' directories.
%
% See also readHarufileDateIndex, harufileFromDate.

x = cell(nRows(t), 1);
hmark = harufileFromDate_CF2(t, hIndex, dir);	% 2xN struct array

[dummy,dummy1,dummy2,dummy3,dummy4,dummy5,sRate,dummy6,dummy7]=readCF2hdr([dir hmark(1,1).hname],0); %get sample rate
%[dummy,sRate] = soundIn([dir hmark(1,1).hname], 0, 0);	% get sample rate

nRows(t);

for i = 1 : nRows(t)
  dIx = hmark(i,1).diskno;	% disk index
  fIx = hmark(i,1).fileno;	% file index (starting at 0)
  nsamp = round(diff(t(i,:)) * 24*60*60 * sRate);
  
  %sam0 = round(hmark(i,1).time * sRate);
  sam0 = hmark(i,1).sample;
  
  while (length(x{i}) < nsamp)
    diskdir = sprintf(iff(nCols(hIndex.time)>1, 'disk%d%s', ''), dIx, filesep);
    fname = [diskdir pathFile(hIndex.hname{fIx + 1, dIx})];
    x{i} = [x{i}; soundIn_CF2_1chan([dir fname], sam0, nsamp - length(x{i}),1)];
    [dIx,fIx] = nextHaruFile(dIx, fIx, hIndex);
    sam0 = 0;
  end
end

