function [ept,yr,jd,hr,mn,sc,samprate,t,y]=readCF2hdr(FILE,datayes) 

% Examples 
% (A) to get the Satrt Time and Sample Rate of a file do the following:
%[ept,yr,jd,hr,mn,sc,samplerate]    = readCF2hdr('/dateDir/00000728.DAT',0); % (A)
%
% (B) to get the Satrt Time, Sample Rate and All the data of a file do the following:
%[ept,yr,jd,hr,mn,sc,samplerate,t,y]= readCF2hdr('/dateDir/00000728.DAT',1);  % (B)
% 
% OUTPUT:
% File's Start Times from the header 
% ept = computed unix time since 1970 
% yr, jd, hr, min, sc of the start time from the header
% samprate = Sample Rate from the header (approx) 
% t = dummy time (computed from ept & samprate) axis for plottting 
% y = time series in counts, i.e. the data points.
% 
% MODIFIED
% February 17th, 2016
%
% CREATED on Sept. 16th, 2013
% This program was based on the script: readH3hdr.m created by
% Dr. Delwayne Bohnenestieh.
%
% Note that t and samprate are approximate. 
% To get real sample rate, difference file start times
% & total data points are needed.

%
% Define the Output variables:
%
  ept = -1;
  yr  = -1;
  jd  = -1;
  hr  = -1;
  mn  = -1;
  sc  = -1;
  t   = [];
  y   = [];

  fid = fopen( FILE, 'r', 'b' );

if fid < 0  % Probelm with the input FILE.
   disp( ['Cannot open the Data file: ', FILE] )
   disp( 'Please check the location of the Data File and try again!' )
   samprate = -1 ;
else
%
   st  = fseek( fid, 152, 'bof' );       % Move to the correct position.
   t1  = fread( fid, 12 );               % Read in the next 12 bytes for the PROGNAME.
%   disp( ['PROGNAME = ', char( t1' )] )  % Shows the PROGNAME
%
   st  = fseek( fid, 90,  'bof' );
   t1  = fread( fid, 64, '*char');       % Get the GMT.
%
   st  = fseek( fid, 196, 'bof' );
   samprate = fread( fid, 1, '*long');   % Sample Rate. 
%
%  Decode the GMT.
%
   yr  = str2num( t1(1:3)'  ) + 1900; 
   jd  = str2num( t1(5:7)'  );
   hr  = str2num( t1(9:10)' );
   mn  = str2num( t1(12:13)');
   sc  = str2num( t1(15:16)') + ( str2num(t1(18:21)')/1000 );
%
%  Compute the start time in seconds since the 1970. 
%
%   ept = 24*60*60*(datenum(yr,1,jd,hr,mn,sc)- datenum(1970,1,1,0,0,0));
 ept = (datenum(yr,1,jd,hr,mn,sc));
%
   if datayes > 0  % Get all the data in the file.
      st  = fseek( fid, 256, 'bof'    );
      y   = fread( fid, inf, 'uint16' ); 
      s   = 1/double( samprate );
      t   = ept: s : (ept+((length(y)-1)*s));
%     Apply the Offset: 2^15 for the Unsigned 16-Bit data,
%     i.e. 2^15=32768 is the data at the range: 0
      y   = y - 32768;   % so that -32768 <= y < +32767
%     y   = y - mean( y );  % Note that mean( y ) may Not = 32768. 
%     plot(t,y);
   end  % Retrieving All the Time Series Data.
%
   fclose( fid );  % Close the input data file.
%
end  % Retrieving Data.

% End of readCF2hdr.m
