% Plot spectrogram of BI during whole deployed period (Figure 2A in Yun et
% al. 2021)
% making spectra data 'Ballenyspectro_15.mat' for deployed period
% Coded by Sukyoung Yun

clear all; close all

psp15 = load('/Volumes/AUH_TNB/Balleny/HC02/AvgSpect.txt');
info15 = load('/Volumes/AUH_TNB/Balleny/HC02/spectroinfo.mat');

recov15 = datenum(2016,3,7); %Recovery dates
tstart = info15.dt0;
tend = info15.dt1;
timegap = tend-recov15; %deployed period
period = info15.period;
fsp = [0.5:1:499.5];
tspB = [tstart+period/2 : period : recov15-period/2]; %remove data after recovery
pspB = psp15(1:end-timegap,:); %remove data after recovery


%% Making Monthly Ticks


for i=1:5
    for j= 1:12
        ticks(j,i)=datenum(i+2014,j,1);
    end
end

ticks = reshape(ticks,[],1);

BItidx = find(ticks > tspB(1) & ticks < tspB(end));
BIticks = ticks(BItidx);

%% Plot
figure(1)
surf(tspB,fsp,pspB','EdgeColor','none'); 
    axis xy; colormap(jet); view(0,90)
    maxc = 95; minc=70;
    axis([tspB(1) tspB(end) 0 450]); 
    caxis([minc maxc]); %axis limit
    ax = gca;
    ax.XTick = BIticks;
    labelstr = datestr(BIticks, 'mmm');
    for i = 1:2:13
        labelstr(i,:)='   ';
    end
    ax.XTickLabel = labelstr;
    ax.XTickLabelRotation = 45;
    set(gca,'LineWidth',2,'Tickdir','out')
%    set(gca,'Ytick',[0:50:500])
    set(gca,'fontsize',12)
    ylabel(['Frequency [Hz]'],'fontsize',15);
    colorbar('location','eastoutside');
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15)
    cbar_handle.Label.String = 'dB re \muPa^{2}/Hz'

        %save figure
    figname =['BI_spectro.tiff']; 
    set(gcf,'PaperPosition',[0,0,13.6,10]);
    print(gcf,'-r300','-dtiff',figname);
    saveas(gcf, 'BI_spectro.jpg');
    save('Ballenyspectro_15.mat', 'pspB', 'tspB');
    