% Plot spectrogram of TNBN during whole deployed period of TNBS(2016-2018)
% Empty data in 2016
% for Figure 2C
% making spectra data 'TNBNspectro_16_18.mat'
% Coded by Sukyoung Yun

clear all; close all

psp16 = load('/Volumes/AUH_TNB/2016/HC14/AvgSpect.txt');
info16 = load('/Volumes/AUH_TNB/2016/HC14/spectroinfo.mat');
psp17 = load('/Volumes/AUH_TNB/2017/HC25/AvgSpect.txt');
info17 = load('/Volumes/AUH_TNB/2017/HC25/spectroinfo.mat');
psp18 = load('/Volumes/AUH_TNB/2018/HC21/AvgSpect.txt');
info18 = load('/Volumes/AUH_TNB/2018/HC21/spectroinfo.mat');

tstart = info16.dt0;
tendN = info18.dt1;
tendS = 737438;
period = info16.period;
fsp = [0.5:1:499.5];
tspN = [tstart+period/2 : period : tendS-period/2];


recov17 = datenum(2018, 3, 11); %recovery date
timegap17 = info17.dt1-recov17;
timegap18NS = tendS-tendN;
empty1 = NaN(info17.dt0 - info16.dt0, 500);
empty2 = NaN(info18.dt0 - recov17,500);
empty3 = NaN(timegap18NS,500);
pspN = [empty1;psp17(1:end-timegap17,:);empty2;psp18;empty3]; 

%% make ticks

for i=1:5
    for j= 1:12
        ticks(j,i)=datenum(i+2014,j,1);
    end
end

ticks = reshape(ticks,[],1);

%TNBtidx = find(ticks > TSWP_TNB(1,1) & ticks < TSWP_TNB(end,1));
TNBticks = ticks(13:49);


%% Figure
figure(1)
surf(tspN,fsp,pspN','EdgeColor','none'); 
    axis xy; colormap(jet); view(0,90)
%    maxc = 115; minc=75;
    maxc = 95; minc=70;
    axis([tspN(1) tspN(end) 0 450]); 
    caxis([minc maxc]); %axis limit
    ax = gca;
    ax.XTick = TNBticks;
    labelstr = datestr(TNBticks, 'mmm');
    for i = 2:2:36
        labelstr(i,:)='   ';
    end
    ax.XTickLabel = labelstr;
    ax.XTickLabelRotation = 45;
    ax.XTick = MoDate;
    set(gca,'LineWidth',2,'Tickdir','out')
%    set(gca,'Ytick',[0:50:500])
    set(gca,'fontsize',12)
    ylabel(['Frequency [Hz]'],'fontsize',15);
    colorbar('location','eastoutside');
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15)
    cbar_handle.Label.String = 'dB re \muPa^{2}/Hz'
        %save figure
    figname =['TNBNorth_spectro.tiff']; 
    set(gcf,'PaperPosition',[0,0,32,10]);
    print(gcf,'-r300','-dtiff',figname);
    saveas(gcf, 'TNBNorth_spectro.jpg'); 
    
    save('TNBNspectro_16_18.mat', 'pspN', 'tspN');
