% Plot spectrogram of TNBS during whole deployed period(2016-2018) for
% Figure 2B
% making spectra data 'TNBSspectro_16_18.mat' for deployed period
% Coded by Sukyoung Yun

clear all; close all

psp16 = load('/Volumes/AUH_TNB/2016/HC14/AvgSpect.txt');
info16 = load('/Volumes/AUH_TNB/2016/HC14/spectroinfo.mat');
psp17 = load('/Volumes/AUH_TNB/2017/HC21/AvgSpect.txt');
info17 = load('/Volumes/AUH_TNB/2017/HC21/spectroinfo.mat');
psp18 = load('/Volumes/AUH_TNB/2018/HC25/AvgSpect.txt');
info18 = load('/Volumes/AUH_TNB/2018/HC25/spectroinfo.mat');

tstart = info16.dt0;
tend = info18.dt1;
period = info16.period;
fsp = [0.5:1:499.5];
tsp = [tstart+period/2 : period : tend-period/2];


recov16 = datenum(2017, 2, 8); %recovery date
mpsp16 = psp16(1:recov16-info16.dt0, :); 
empty1 = NaN(info17.dt0 - recov16, 500);
empty2 = NaN(info18.dt0 - info17.dt1,500);
psp = [mpsp16 ; empty1;psp17;empty2;psp18]; 

%% Making Monthly Ticks

for i=1:5
    for j= 1:12
        ticks(j,i)=datenum(i+2014,j,1);
    end
end

ticks = reshape(ticks,[],1);

%TNBtidx = find(ticks > TSWP_TNB(1,1) & ticks < TSWP_TNB(end,1));
TNBticks = ticks(13:49);



figure(1)
surf(tsp,fsp,psp','EdgeColor','none'); 
    axis xy; colormap(jet); view(0,90)
    axis([tsp(1) tsp(end) 0 450]); 
    maxc = 95; minc=70;
    caxis([minc maxc]); %axis limit
    ax = gca;
    ax.XTick = TNBticks;
    labelstr = datestr(TNBticks, 'mmm');
    for i = 2:2:36
        labelstr(i,:)='   ';
    end
    ax.XTickLabel = labelstr;
    ax.XTickLabelRotation = 45;
    set(gca,'LineWidth',2,'Tickdir','out')
%    set(gca,'Ytick',[0:50:500])
    set(gca,'fontsize',12)
    ylabel(['Frequency [Hz]'],'fontsize',15);
    colorbar('location','eastoutside');
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15)
    cbar_handle.Label.String = 'dB re \muPa^{2}/Hz'
        %save figure
    figname =['TNBSouth_spectro.tiff']; 
    set(gcf,'PaperPosition',[0,0,32,10]);
    print(gcf,'-r300','-dtiff',figname);
    saveas(gcf, 'TNBSouth_spectro.jpg'); 
    save('TNBSspectro_16_18.mat', 'pspS', 'tspS');