% This code calculates spectral density of BAL15 and plots Figure 3 in (Yun et al., 2021) 
% 'AvgSpect.txt' and 'spectroinfo.mat' files calculated from 1.SpectaCalculation are required
% Coded by Sukyoung Yun 
% ver1.0.0 in Oct 2021


clear all; close all;
maindir = '/Volumes/AUH_TNB/Balleny/HC02/'; %working directory

pts = 50:0.25:120; %dB values where the density estimate
fsp = [0.5:1:499.5]; %mid point of the 
recov15 = datenum(2016,3,7); %Recovery dates

%BI 2015 HC02
load([maindir,'spectroinfo.mat']);
psp=load([maindir,'AvgSpect.txt']);
timegap = dt1-recov15;
spectro = psp(1:end-timegap,:);
tsp = [dt0+period/2 : period : recov15-period/2];
ymd = datevec(tsp);

winteridx = find(ymd(:,2)>5 & ymd(:,2)< 9); %Jun-Aug
EarSummeridx = find(ymd(:,2)> 10); % Nov-Dec
LatSummeridx = find(ymd(:,2)<5 & ymd(:,1)==2015); %Jan-Apr

    
for m=1:500
    [pdtotal(m,:), xi] = ksdensity(spectro(:,m),pts,'width',0.5);
    [pdwinter(m,:), xi] = ksdensity(spectro(winteridx,m),pts,'width',0.5);
    [pdES(m,:), xi] = ksdensity(spectro(EarSummeridx,m),pts,'width',0.5);
    [pdLS(m,:), xi] = ksdensity(spectro(LatSummeridx,m),pts,'width',0.5);
end

%% plot pdf whole period

    surf(fsp,xi,pdtotal','EdgeColor','none'); 
    axis xy; colormap(jet); view(0,90)
    maxc=prctile(pdtotal(:),99.5); % higest 99.5%
    minc=prctile(pdtotal(:),50); % lowest 50%
    axis([0 450 60 105]); 
    caxis([minc maxc]); %axis limit
    set(gca,'fontsize',17)
    set(gca,'LineWidth',2,'Tickdir','out','XTick',[0:50:450])
    set(gca,'XGrid','on','Gridcolor','w','Layer','top')
    xlabel(['Frequency [Hz]'],'fontsize',18);
    ylabel(['dB re \muPa^{2}/Hz'],'fontsize',18);
    colorbar('location','eastoutside');
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15)
    cbar_handle.Label.String = 'Probability Density'
    %save figure
    figname =[locname,'_pdf_total.tiff']; 
    set(gcf,'PaperPosition',[0,0,18, 14]);
    print(gcf,'-r200','-dtiff',figname);
    saveas(gcf, [locname,'_pdf_total.jpg']);
    close all
    
%% plot pdf Winter
    surf(fsp,xi,pdwinter','EdgeColor','none'); 
    axis xy; colormap(jet); view(0,90)
    maxc=prctile(pdwinter(:),99.5); % higest 99.5%
    minc=prctile(pdwinter(:),50); % lowest 50%
    axis([0 450 60 105]); 
    caxis([minc maxc]); %axis limit
    set(gca,'fontsize',17)
    set(gca,'LineWidth',2,'Tickdir','out','XTick',[0:50:450])
    set(gca,'XGrid','on','Gridcolor','w','Layer','top')
    xlabel(['Frequency [Hz]'],'fontsize',18);
    ylabel(['dB re \muPa^{2}/Hz'],'fontsize',18);
    colorbar('location','eastoutside');
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15)
    cbar_handle.Label.String = 'Probability Density'
    %title('2017? 6~8? (??) ?????');
    %save figure
    figname =[locname,'_pdf_winter.tiff']; 
    set(gcf,'PaperPosition',[0,0,18, 14]);
    print(gcf,'-r200','-dtiff',figname);
    saveas(gcf, [locname,'_pdf_winter.jpg']);
    close all
    
%% pdf Early Summer
    surf(fsp,xi,pdES','EdgeColor','none'); 
    axis xy; colormap(jet); view(0,90)

    maxc=prctile(pdES(:),99.5); % higest 99.5%
    minc=prctile(pdES(:),50); % lowest 50%
    axis([0 450 60 105]); 
    caxis([minc maxc]); %axis limit
    set(gca,'fontsize',17)
    set(gca,'LineWidth',2,'Tickdir','out','XTick',[0:50:450])
    set(gca,'XGrid','on','Gridcolor','w','Layer','top')
    xlabel(['Frequency [Hz]'],'fontsize',18);
    ylabel(['dB re \muPa^{2}/Hz'],'fontsize',18);
    colorbar('location','eastoutside');
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15)
    cbar_handle.Label.String = 'Probability Density'
    %save figure
    figname =[locname,'_pdfES.tiff']; 
    set(gcf,'PaperPosition',[0,0,18, 14]);
    print(gcf,'-r200','-dtiff',figname);
    saveas(gcf, [locname,'_pdfES.jpg']);
    close all
    
    
%% plot pdf Late summer
    surf(fsp,xi,pdLS','EdgeColor','none'); 
    axis xy; colormap(jet); view(0,90)
    maxc=prctile(pdLS(:),99.5); % higest 99.5%
    minc=prctile(pdLS(:),50); % lowest 50%
    axis([10 100 60 105]); %X axis range 10-100 Hz
    caxis([minc maxc]); %axis limit
    set(gca,'fontsize',17)
    set(gca,'LineWidth',2,'Tickdir','out','XTick',[10:10:100])
    set(gca,'XGrid','on','Gridcolor','w','Layer','top')
    xlabel(['Frequency [Hz]'],'fontsize',18);
    ylabel(['dB re \muPa^{2}/Hz'],'fontsize',18);
    colorbar('location','eastoutside');
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15)
    cbar_handle.Label.String = 'Probability Density'
    %save figure
    figname =[locname,'_pdfLS.tiff']; 
    set(gcf,'PaperPosition',[0,0,18, 14]);
    print(gcf,'-r200','-dtiff',figname);
    saveas(gcf, [locname,'_pdfLS.jpg']);    
    close all