% This code calculates PSDMMC(Menze et al., 2017) in BI and makes a timeseries plot (Figure S3, 4B)
% This code plots diel cycle of PSDMMCs after Menze et al. (2017) (Figure 6, Figure S5) 
% hourly averaged spectrogram data (by 1.SpectrCalculation) are required 
% Coded by Sukyoung Yun

clear all; close all;
psp = load('AvgSpect_BI_15_1hr.txt');
load('spectroinfo_BI_15_1hr.mat');
recov=datenum(2016,3,7); %recovery date
fsp = [0.5:1:499.5];
tsp = [dt0+period/2 : period : recov-period/2];
psp = psp(1:size(tsp,2),:);

%% Plot samples to check the core frequency window (Fig. S2 in Yun et al., 2021)

Dtime = datenum(2015,6, 20, 12,0,0); %sample date &time
idx = (Dtime-dt0)*24+1;  %idx of the sample date
idx = round(idx); 

plot(fsp,psp(idx,:),'-','Color','k','LineWidth',1.5) 
%semilogx(fsp,psp(idx,:),'-','Color','k','LineWidth',1.5)

xlim([0 65]); ylim([78 95]);
grid on; hold on;

%%Whale
ipbx1= [7.5:1:12.5 39.5:2:59.5]; %in frequency Hz
idx1 = ipbx1+0.5; %index of the ipbx1
t1=7.5:1:59.5;
p1 = fit(ipbx1', psp(idx,idx1)', 'power2');
ty1 = feval(p1,t1); 
h=plot(ipbx1, psp(idx,idx1), 'or');
h.Annotation.LegendInformation.IconDisplayStyle = 'off';
plot(t1, ty1,'-r','Linewidth',1 );


%%Minkewhale from [2/1-9/31]
ipbx2= [39.5:2:65.5 300.5:2:350.5];
idx2 = ipbx2+0.5; %index of the ipbx1
t2=39.5:1:350.5;
p2 = fit(ipbx2', psp(idx,idx2)', 'power2');
ty2 = feval(p2,t2); 
h2=plot(ipbx2(1:14), psp(idx,idx2(1:14)),'o', 'Color', [0.8 0.3 0]);
h3=plot(ipbx2(15:end), psp(idx,idx2(15:end)),'o', 'Color', [0.5 0.5 0]);
h2.Annotation.LegendInformation.IconDisplayStyle = 'off';
h3.Annotation.LegendInformation.IconDisplayStyle = 'off';
plot(t2,ty2,'-','Color', [0.5 0.5 0],'Linewidth',1);

%plot MMC range
ABWbd = 25.5:1:27.5;
ABWidx= ABWbd+0.5;
ABWarea = [25 25 28 28];
areaY = [50 130 130 50];
MWbd = 103.5:1:210.5;
MWidx = MWbd+0.5;
MWarea = [103, 103, 211, 211];

fill(ABWarea, areaY,'r','LineStyle','none','FaceAlpha',0.3);
fill(MWarea, areaY,[0.5 0.5 0],'LineStyle','none','FaceAlpha',0.3);
legend('recorded PSD <2015.06.20. 12:00>','interpolated PSD in Ant. blue whale band',...
    'interpolated PSD in Ant. minke whale band [Feb-Sep]','Location','northeast','FontSize',10);
set(gca,'LineWidth',2,'Tickdir','in');
set(gca,'fontsize',15);
ylabel('PSD [dB re \muPa^{2}/Hz]','fontsize',18);
xlabel('Frequency [Hz]','fontsize',18);
title('BAL15','fontsize',18)

%save figure
figname ='intp_band_BIwinter.tiff'; 
set(gcf,'PaperPosition',[0,0,15,10])
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'intp_band_BIwinter.jpg');


% For summer season, Leopard seals
close all; clear idx h h1 h2;
Dtime = datenum(2015,12, 10, 12,0,0);
idx = (Dtime-dt0)*24+1;
idx = round(idx);

plot(fsp,psp(idx,:),'-','Color','k','LineWidth',1.5)

%semilogx(fsp,psp(idx,:),'-','Color','k','LineWidth',1.5)
xlim([0 500]); ylim([68 100]);
grid on; hold on;

%%Leopard seals
ipbx3= [39.5:2:160.5 412.5:1:440.5]; %in frequency Hz
idx3 = ipbx3+0.5; %index of the ipbx1
t3=39.5:1:439.5;
p3 = fit(ipbx3', psp(idx,idx3)', 'power2');
ty3 = feval(p3,t3); 
h=plot(ipbx3, psp(idx,idx3), 'go');
h.Annotation.LegendInformation.IconDisplayStyle = 'off';
plot(t3,ty3,'g-','LineWidth',1);

%LS band
LSbd = 310.5:1:359.5;
LSidx = LSbd+0.5;
LSarea = [310 310 360 360];
fill(LSarea, areaY,'g','LineStyle','none','FaceAlpha',0.3);
legend('recorded PSD <2015.12.10. 12:00>',...
    'interpolated PSD in Leopard seals band [Oct-Jan]','Location','northwest','FontSize',10);
set(gca,'LineWidth',2,'Tickdir','in');
set(gca,'fontsize',15);
ylabel('PSD [dB re \muPa^{2}/Hz]','fontsize',18);
xlabel('Frequency [Hz]','fontsize',18);
title('BAL15', 'fontsize',18);

%save figure
figname =['intp_band_BIsummer.tiff']; 
set(gcf,'PaperPosition',[0,0,15,10])
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'intp_band_BIsummer.jpg');
close all;


%% Calculating PSDMMC
nf1 = size(ABWbd,2); nf2 = size(MWbd,2); nf3 = size(LSbd,2);
itpidx1 = find(t1>=ABWbd(1) & t1<=ABWbd(end)); %%corefrequency index in t
itpidx2 = find(t2>=MWbd(1) & t2<=MWbd(end));
itpidx3 = find(t3>=LSbd(1) & t3<=LSbd(end));
for i=1:size(psp,1)
    %ABW PSDint
    clear p1 p2 p3
    [p1, sta] = fit(ipbx1', psp(i,idx1)', 'power2');
    rs(i,1)=sta.rsquare;
    PSD_m1 = mean(10.^(psp(i,ABWidx)./10));
    PSD_i1 = mean(10.^(feval(p1,t1(itpidx1))./10));
    if 10*log10(PSD_m1) - 10*log10(PSD_i1)>1
        PSD(i,1) = 10.*log10(PSD_m1-PSD_i1);
    else
        PSD(i,1) = NaN;
    end
    

    [p2, sta] = fit(ipbx2', psp(i,idx2)', 'power2');
    rs(i,2)=sta.rsquare;
    PSD_m2 = mean(10.^(psp(i,MWidx)./10));
    PSD_i2 = mean(10.^(feval(p2,t2(itpidx2))./10));
    if 10*log10(PSD_m2) - 10*log10(PSD_i2)>1
        PSD(i,2) = 10.*log10(PSD_m2-PSD_i2);
    else
        PSD(i,2) = NaN;
    end
    
    [p3, sta] = fit(ipbx3', psp(i,idx3)', 'power2');
    rs(i,3)=sta.rsquare;
    PSD_m3 = mean(10.^(psp(i,LSidx)./10));
    PSD_i3 = mean(10.^(feval(p3,t3(itpidx3))./10));
    if 10*log10(PSD_m3) - 10*log10(PSD_i3)>1
        PSD(i,3) = 10.*log10(PSD_m3-PSD_i3);
    else
        PSD(i,3) = NaN;
    end    
end

%% Plot PSDmmc timeseries (for Fig. 4B in Yun et al., 2021)
%make ticks
for i=1:5
    for j= 1:12
        ticks(j,i)=datenum(i+2014,j,1);
    end
end

ticks = reshape(ticks,[],1);
BItidx = find(ticks > tsp(1) & ticks < tsp(end));
BIticks = ticks(BItidx);

%Minkewhale period
MWperiod(1) = datenum(2015,2,1); 
MWperiod(2) = datenum(2015,10,1); 
MWperiod(3) = datenum(2016,2,1); 
MWPidx1 = find(tsp>=MWperiod(1) & tsp<MWperiod(2));
MWPidx2 = find(tsp>=MWperiod(3));
MWPidx = [MWPidx1 MWPidx2];
%Leopard seals period
LSPidx1 = find(tsp<MWperiod(1));
LSPidx2 = find(tsp>=MWperiod(2) & tsp<MWperiod(3));
LSPidx = [LSPidx1 LSPidx2];

% Period filtering : Change values into NaN 
PSDf = PSD;
PSDf(LSPidx,2) = NaN;
PSDf(MWPidx,3) = NaN;
rsf = rs;
rsf(LSPidx,2) = NaN;
rsf(MWPidx,3) = NaN;
rmean = nanmean(rsf,1);

MPSD= movmean(PSDf,24,1); % 24h averaged value 

%figure(1)
plot(tsp, MPSD(:,1),'r-','LineWidth',1);
hold on
plot(tsp, MPSD(:,2),'-', 'Color', [0.5 0.5 0], 'LineWidth',1);
plot(tsp, MPSD(:,3),'g-', 'LineWidth',1);
lgd=legend('Antarctic blue whale [25-28 Hz]', 'Antarctic minke whale (Feb-Sep) [103-211 Hz]',...
    'Leopard seal (Oct-Jan) [310-360 Hz]','Location','best', 'FontSize',10);
%lgd.NumColumns = 2;
ylim([65 115]);
ax=gca;
ax.XLim = [tsp(1) tsp(end)];
ax.XTick = BIticks;
ax.XTickLabel = datestr(BIticks, 'mmm');
ax.XTickLabelRotation = 45;
set(gca,'LineWidth',2,'Tickdir','in')
set(gca,'fontsize',13)
ylabel({'PSD_{MMC}', '[dB re 1 \muPa^{2}/Hz]'}, 'fontsize',13);

grid on 

figname =['PSD_MMC_BI.tiff']; 
set(gcf,'PaperPosition',[0,0,23,7])
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'PSD_MMC_BI.jpg');
close all;

%% Diel Cycle (for Fig. 6)
%LT=UTC+11 (lon=165E)
%Daily normalized Level
PSDpa = 10.^(PSDf./10); %dB->pa^2
DD = ceil(tsp(1)):1:floor(tsp(end)); 
NANpsd = isnan(PSD);
BWnorm=[]; MWnorm=[]; LSnorm=[];  %[date normPSD] for BlueW/MinkeW/LeopardS
DailyBI = nan(size(DD,2),4);
DailyBI(:,1) = DD';
for i=1:size(DD,2)
    idx=find(floor(tsp)==DD(i));
    if all(NANpsd(idx,1)==0) %normalization for no NAN in a day 
        a=PSDpa(idx,1)';
        b= (a - min(a)) ./ (max(a) -min(a)) ;
        BWnorm = [BWnorm; DD(i) b];
        DailyBI(i,2)=log10(mean(PSDpa(idx,1),1)).*10;
    end
    if all(NANpsd(idx,2)==0) %no NAN value case for MW
        a=PSDpa(idx,2)';
        b= (a - min(a)) ./ (max(a) -min(a)) ;
        MWnorm = [MWnorm; DD(i) b];
        DailyBI(i,3)=log10(mean(PSDpa(idx,2),1)).*10;
    end
    if all(NANpsd(idx,3)==0) %no NAN value case for LS
        a=PSDpa(idx,3)';
        b= (a - min(a)) ./ (max(a) -min(a)) ;
        LSnorm = [LSnorm; DD(i) b];
        DailyBI(i,4)=log10(mean(PSDpa(idx,3),1)).*10;
    end

end
save('DailyPSDmmc_BI.txt', 'DailyBI', '-ascii', '-tabs');
% Statistic plots
tticks = 0.5:1:25.5;
ttickslabel = {'0:00', ' ', ' ', ' ', '4:00', ' ', ' ', ' ','8:00',...
    ' ', ' ', ' ', '12:00',' ', ' ', ' ', '16:00',' ', ' ', ' ', '20:00',...
    ' ', ' ',' ', '24:00'};


figure(1)
subplot(3,1,1)
boxplot(BWnorm(:,2:end),'Widths',1,'Whisker',0, 'symbol', '');
set(gca,'Xtick',tticks,'XTickLabel',ttickslabel, 'xticklabelrotation',0);
ylabel('normPSD_{MMC}')
subtitle('BI Antarctic blue whale [25-28 Hz]')
subplot(3,1,2)
boxplot(MWnorm(:,2:end),'Widths',1,'Whisker',0, 'symbol', '');
set(gca,'Xtick',tticks,'XTickLabel',ttickslabel, 'xticklabelrotation',0);
ylabel('normPSD_{MMC}')
subtitle('BI Antarctic minke whale [103-211 Hz]')
subplot(3,1,3)
boxplot(LSnorm(:,2:end),'Widths',1,'Whisker',0, 'symbol', '');
set(gca,'Xtick',tticks,'XTickLabel',ttickslabel, 'xticklabelrotation',0);
xlabel('Time (Hours)')
ylabel('normPSD_{MMC}')
subtitle('BI Leopard seal [310-360 Hz]')

figname =['nPSD_Diel_BI.tiff']; 
set(gcf,'PaperPosition',[0,0,15,20])
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'nPSD_Diel_BI.jpg');
close all;


%% plots for specific month (Fig. S5)
MWdates = datevec(MWnorm(:,1));
figure(1)
subplot(2,1,1)
idx = find(MWdates(:,2) < 8);
boxplot(MWnorm(idx,2:end),'Widths',1,'Whisker',0, 'symbol', '');
set(gca,'Xtick',tticks,'XTickLabel',ttickslabel, 'xticklabelrotation',0);
ylabel('normPSD_{MMC}')
subtitle('Antarctic minke whale during May-July')
subplot(2,1,2)
clear idx;
idx = find(MWdates(:,2) > 7);
boxplot(MWnorm(idx,2:end),'Widths',1,'Whisker',0, 'symbol', '');
set(gca,'Xtick',tticks,'XTickLabel',ttickslabel, 'xticklabelrotation',0);
xlabel('Time (Hours)')
ylabel('normPSD_{MMC}')
subtitle('Antarctic minke whale during Aug-Oct')

figname =['nPSD_MW_Diel_BI.tiff']; 
set(gcf,'PaperPosition',[0,0,15,15])
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'nPSD_MW_Diel_BI.jpg');
close all;