% This code calculates PSDMMC (Menze et al., 2017) in TNB and makes a timeseries plot (Figure S3, 4B)
% This code plots diel cycle of PSDMMCs after Menze et al. (2017) (Figure 7) 
% hourly averaged spectrogram data (by 1.SpectrCalculation) are required 
% Coded by Sukyoung Yun


clear all; close all;

psp16S = load('AvgSpect_TNBS_16_1hr.txt');
info16S= load('spectroinfo_TNBS_16_1hr.mat');
psp17S = load('AvgSpect_TNBS_17_1hr.txt');
info17S= load('spectroinfo_TNBS_17_1hr.mat');
psp18S = load('AvgSpect_TNBS_18_1hr.txt');
info18S= load('spectroinfo_TNBS_18_1hr.mat');

tstart = info16S.dt0;
tend = info18S.dt1;
period = info16S.period; % 1/24 
fsp = [0.5:1:499.5];
tsp = [tstart+period/2 : period : tend-period/2];


recov16S = datenum(2017, 2, 8); %recovery date
mpsp16S = psp16S(1:round((recov16S-info16S.dt0)*24), :); 
empty1 = NaN(round((info17S.dt0 - recov16S)*24), 500);
empty2 = NaN(round((info18S.dt0 - info17S.dt1)*24),500);
psp = [mpsp16S ; empty1;psp17S;empty2;psp18S]; 


%% Plot samples to check the core frequency window (Fig. S2 in Yun et al., 2021)

Dtime = datenum(2017, 3, 15, 12, 0,0); %sample date &time
idx = (Dtime-tstart)*24+1;  %idx of the sample date
idx = round(idx); 

plot(fsp,psp(idx,:),'-','Color','k','LineWidth',1.5) 
xlim([0 100]); 
ylim([85 100]);
grid on; hold on;

%%Blue Whale
ipbx1= [18.5:1:23.5 29.5:1:41.5]; %in frequency Hz
idx1 = ipbx1+0.5; %index of the ipbx1
t1=18.5:1:41.5;
p1 = fit(ipbx1', psp(idx,idx1)', 'power2');
ty1 = feval(p1,t1); 
h=plot(ipbx1, psp(idx,idx1), 'or');
h.Annotation.LegendInformation.IconDisplayStyle = 'off';
plot(t1, ty1,'-r','Linewidth',1 );

%plot MMC range
ABWbd = [25.5:1:27.5];
ABWidx= ABWbd+0.5;
ABWarea = [25 25 28 28];
areaY = [50 130 130 50];
fill(ABWarea, areaY,'r','LineStyle','none','FaceAlpha',0.3);
legend('recorded PSD <2017.03.15. 12:00>','interpolated PSD in Ant. blue whale band',...
    'Location','northeast','FontSize',10);
set(gca,'LineWidth',2,'Tickdir','in');
set(gca,'fontsize',15);
ylabel('PSD [dB re \muPa^{2}/Hz]','fontsize',18);
xlabel('Frequency [Hz]','fontsize',18);
title('TNBS','fontsize',18)
%save figure
figname =['intp_band_TNBS3Y_BW.tiff']; 
set(gcf,'PaperPosition',[0,0,15,10])
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'intp_band_TNBS3Y_BW.jpg');
close all

% Plot samples for LS

Dtime = datenum(2017, 12, 10, 20, 0,0); %sample date &time
idx = (Dtime-tstart)*24+1;  %idx of the sample date
idx = round(idx); 

plot(fsp,psp(idx,:),'-','Color','k','LineWidth',1.5) 
xlim([0 500]); 
ylim([70 95]);
grid on; hold on;
ipbx2= [90.5:1:145.5 400.5:1:420.5];
idx2 = ipbx2+0.5; %index of the ipbx1
t2=90.5:1:420.5;
p2 = fit(ipbx2', psp(idx,idx2)', 'power2');
ty2 = feval(p2,t2); 
h2=plot(ipbx2, psp(idx,idx2),'go');
h2.Annotation.LegendInformation.IconDisplayStyle = 'off';
h3=plot(t2,ty2,'g-','Linewidth',1);
h3.Annotation.LegendInformation.IconDisplayStyle = 'off';

Dtime = datenum(2017, 8, 20, 12, 0,0); %sample date &time
idx = (Dtime-tstart)*24+1;  %idx of the sample date
idx = round(idx); 

plot(fsp,psp(idx,:),'--','Color','k','LineWidth',1.5) 
p2 = fit(ipbx2', psp(idx,idx2)', 'power2');
ty2 = feval(p2,t2); 
h4=plot(ipbx2, psp(idx,idx2),'go');
h4.Annotation.LegendInformation.IconDisplayStyle = 'off';
plot(t2,ty2,'g-','Linewidth',1);

LSbd = 310.5:1:359.5;
LSidx = LSbd+0.5;
LSarea = [310 310 360 360];
fill(LSarea, areaY,'g','LineStyle','none','FaceAlpha',0.3);
legend('recorded PSD <2017.12.10. 20:00>','recorded PSD <2017.08.20. 12:00>',...
    'interpolated PSD in Leopard seals band','Location','northeast','FontSize',10);
set(gca,'LineWidth',2,'Tickdir','in');
set(gca,'fontsize',15);
ylabel('PSD [dB re \muPa^{2}/Hz]','fontsize',18);
xlabel('Frequency [Hz]','fontsize',18);
title('TNBS','fontsize',18)
%save figure
figname =['intp_band_TNBS3Y_LS.tiff']; 
set(gcf,'PaperPosition',[0,0,15,10])
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'intp_band_TNBS3Y_LS.jpg');
close all;

%% Calculated PSD MMC in TNBS
nf1 = size(ABWbd,2); nf2 = size(LSbd,2);
itpidx1 = find(t1>=ABWbd(1) & t1<=ABWbd(end)); %%corefrequency index in t
itpidx2 = find(t2>=LSbd(1) & t2<=LSbd(end));


for i=1:size(psp,1)
    %ABW PSDint
    clear p1 p2 p3
    if isnan(psp(i,1)) == 1
        PSD(i,1) = NaN;
        PSD(i,2) = NaN;
    else
        [p1, sta] = fit(ipbx1', psp(i,idx1)', 'power2');
        rs(i,1)=sta.rsquare;
        PSD_m1 = mean(10.^(psp(i,ABWidx)./10));
        PSD_i1 = mean(10.^(feval(p1,t1(itpidx1))./10));
        if 10*log10(PSD_m1) - 10*log10(PSD_i1)>1
            PSD(i,1) = 10.*log10(PSD_m1-PSD_i1);
        else
            PSD(i,1) = NaN;
        end


        [p2, sta] = fit(ipbx2', psp(i,idx2)', 'power2');
        rs(i,2)=sta.rsquare;
        PSD_m2 = mean(10.^(psp(i,LSidx)./10));
        PSD_i2 = mean(10.^(feval(p2,t2(itpidx2))./10));
        if 10*log10(PSD_m2) - 10*log10(PSD_i2)>1
            PSD(i,2) = 10.*log10(PSD_m2-PSD_i2);
        else
            PSD(i,2) = NaN;
        end
    end
    
end



%% Calculated PSDMMC in TNBN
psp17N = load('AvgSpect_TNBN_17_1hr.txt');
info17N= load('spectroinfo_TNBN_17_1hr.mat');
psp18N = load('AvgSpect_TNBN_18_1hr.txt');
info18N= load('spectroinfo_TNBN_18_1hr.mat');

%tstart = info17N.dt0;
%tend = info18N.dt1;
%period = info17N.period; % 1/24 
%fsp = [0.5:1:499.5];
%tsp = [tstart+period/2 : period : tend-period/2];


recov17 = datenum(2018, 3, 11);
mpsp17N = psp17N(1:round((recov17-info17N.dt0)*24), :);
empty1 = NaN(round((info17N.dt0 - info16S.dt0)*24), 500);
empty2 = NaN(round((info18N.dt0 - recov17)*24),500);
empty3 = NaN(round((info18S.dt1 - info18N.dt1)*24),500);
pspN =[empty1;mpsp17N;empty2;psp18N;empty3];



for i=1:size(pspN,1)
    %ABW PSDint
    clear p1 p2 p3
    if isnan(pspN(i,1)) == 1
        PSDN(i,1) = NaN;
        PSDN(i,2) = NaN;
    else
        [p1, sta] = fit(ipbx1', pspN(i,idx1)', 'power2');
        rsN(i,1)=sta.rsquare;
        PSD_m1 = mean(10.^(pspN(i,ABWidx)./10));
        PSD_i1 = mean(10.^(feval(p1,t1(itpidx1))./10));
        if 10*log10(PSD_m1) - 10*log10(PSD_i1)>1
            PSDN(i,1) = 10.*log10(PSD_m1-PSD_i1);
        else
            PSDN(i,1) = NaN;
        end


        [p2, sta] = fit(ipbx2', pspN(i,idx2)', 'power2');
        rsN(i,2)=sta.rsquare;
        PSD_m2 = mean(10.^(pspN(i,LSidx)./10));
        PSD_i2 = mean(10.^(feval(p2,t2(itpidx2))./10));
        if 10*log10(PSD_m2) - 10*log10(PSD_i2)>1
            PSDN(i,2) = 10.*log10(PSD_m2-PSD_i2);
        else
            PSDN(i,2) = NaN;
        end
    end
    
end

%% Rsquare
rsf = [rs;rsN];
rmean = nanmean(rsf,1);

%% Plot PSDmmc timeseries in TNB (Fig.5B in Yun et al., 2021)
%make ticks
for i=1:5
    for j= 1:12
        ticks(j,i)=datenum(i+2014,j,1);
    end
end

ticks = reshape(ticks,[],1);
TNBtidx = find(ticks > tsp(1) & ticks < tsp(end));
TNBticks = ticks(TNBtidx);

MPSD= movmean(PSD,24,1); %24h average 
MPSDN= movmean(PSDN,24,1); %24h average 
%figure(1)
plot(tsp, MPSD(:,1),'m-',tsp, MPSD(:,2),'g-','LineWidth',1);
hold on
plot(tsp, MPSDN(:,1),'-','Color',[0.6 0.1 0.1],'LineWidth',1);
plot(tsp, MPSDN(:,2),'-','Color',[0 0.6 0.5],'LineWidth',1);
lgd=legend('TNBS','TNBS',...
    'TNBN  Antarctic blue whale [25-28 Hz]','TNBN  Leopard seal [310-360 Hz]',...
    'Location','northwest', 'FontSize',10);
lgd.NumColumns = 2;
ylim([65 105]);
ax=gca;
ax.XLim = [tsp(1) tsp(end)];
ax.XTick = TNBticks;
labelstr = datestr(TNBticks, 'mmm');
    for i = 2:2:36
        labelstr(i,:)='   ';
    end
ax.XTickLabel = labelstr;
ax.XTickLabelRotation = 45;
set(gca,'LineWidth',2,'Tickdir','in')
set(gca,'fontsize',13)
ylabel({'PSD_{MMC}', '[dB re 1 \muPa^{2}/Hz]'}, 'fontsize',13);

grid on 

figname =['PSD_MMC_TNB3Y.tiff']; 
set(gcf,'PaperPosition',[0,0,23,7])
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'PSD_MMC_TNB3Y.jpg');
close all;

%% Diel Cycle (for Fig. 7)
%LT=UTC+11 (lon=165E)
%Daily normalized Level
PSDpa = 10.^(PSD./10); %dB->pa^2
PSDpaN = 10.^(PSDN./10);
DD = ceil(tsp(1)):1:floor(tsp(end)); 
NANpsd = isnan(PSD);
NANpsdN = isnan(PSDN);
BWnorm=[]; LSnorm=[];  %[date normPSD] for BlueW/MinkeW/LeopardS
BWnormN=[]; LSnormN=[];  %[date normPSD] for BlueW/MinkeW/LeopardS
DailyTNBS = nan(size(DD,2),3); DailyTNBN=nan(size(DD,2),3);
DailyTNBS(:,1) = DD'; DailyTNBN(:,1) = DD'; 
for i=1:size(DD,2)
    idx=find(floor(tsp)==DD(i));
    if all(NANpsd(idx,1)==0) %normalization for no NAN in a day 
        a=PSDpa(idx,1)';
        b= (a - min(a)) ./ (max(a) -min(a)) ;
        BWnorm = [BWnorm; DD(i) b];
        DailyTNBS(i,2)=log10(mean(PSDpa(idx,1),1)).*10;
    end
    if all(NANpsd(idx,2)==0) %no NAN value case for LS
        a=PSDpa(idx,2)';
        b= (a - min(a)) ./ (max(a) -min(a)) ;
        LSnorm = [LSnorm; DD(i) b];
        DailyTNBS(i,3)=log10(mean(PSDpa(idx,2),1)).*10;
    end

    if all(NANpsdN(idx,1)==0) %normalization for no NAN in a day 
        a=PSDpaN(idx,1)';
        b= (a - min(a)) ./ (max(a) -min(a)) ;
        BWnormN = [BWnormN; DD(i) b];
        DailyTNBN(i,2)=log10(mean(PSDpaN(idx,1),1)).*10;
    end
    if all(NANpsdN(idx,2)==0) %no NAN value case for LS
        a=PSDpaN(idx,2)';
        b= (a - min(a)) ./ (max(a) -min(a)) ;
        LSnormN = [LSnormN; DD(i) b];
        DailyTNBN(i,3)=log10(mean(PSDpaN(idx,2),1)).*10;
    end
    
end

save('DailyPSDmmc_TNBS.txt', 'DailyTNBS', '-ascii', '-tabs');
save('DailyPSDmmc_TNBN.txt', 'DailyTNBN', '-ascii', '-tabs');

BWnorm = [BWnorm; BWnormN];
LSnorm = [LSnorm; LSnormN];
% Statistic plots
tticks = 0.5:1:25.5;
ttickslabel = {'0:00', ' ', ' ', ' ', '4:00', ' ', ' ', ' ','8:00',...
    ' ', ' ', ' ', '12:00',' ', ' ', ' ', '16:00',' ', ' ', ' ', '20:00',...
    ' ', ' ',' ', '24:00'};


figure(1)
subplot(2,1,1)
boxplot(BWnorm(:,2:end),'Widths',1,'Whisker',0, 'symbol', '');
set(gca,'Xtick',tticks,'XTickLabel',ttickslabel, 'xticklabelrotation',0);
ylabel('normPSD_{MMC}')
subtitle('TNB Antarctic blue whale [25-28 Hz]')
subplot(2,1,2)
boxplot(LSnorm(:,2:end),'Widths',1,'Whisker',0, 'symbol', '');
set(gca,'Xtick',tticks,'XTickLabel',ttickslabel, 'xticklabelrotation',0);
ylabel('normPSD_{MMC}')
subtitle('Leopard seal')
xlabel('Time (Hours)')
subtitle('TNB Leopard seal [310-360 Hz]')

figname =['nPSD_Diel_TNB.tiff']; 
set(gcf,'PaperPosition',[0,0,15,15])
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'nPSD_Diel_TNB.jpg');
close all;
