% Codes to analyze correlation between PSD and Sea Ice, Wind 
% This code makes plots for Figures 4,5,8,9, and S6 in Yun et al. (2021)
% Coded by Sukyoung Yun


clear all; close all;
FigABC = ['(A)'; '(B)'; '(C)'; '(D)'; '(E)'; '(F)'; '(G)'; '(H)']; 
datadir = './T_Wind_SI_Dataset/';

%% 1. Set Frequency range for Fig 4A, 5A
fsp = [0.5:1:499.5];
FB(1,:) = [15 30]; % Fin and Blue whales
FB(2,:) = [50 65]; % Icequakes
FB(3,:) = [300 350]; % Leopard seals; also signals in 200-250 Hz
FB(4,:) = [10 400]; %total

%% 1.1. Set Monthly datenum

for i=1:5
    for j= 1:12
        ticks(j,i)=datenum(i+2014,j,1);
    end
end

ticks = reshape(ticks,[],1);


%% 2.1. load psp 
% spectro data are generated from "2.PlotSpectrogram"
load([datadir, 'TNBSspectro_16_18.mat']);
load([datadir, 'TNBNspectro_16_18.mat']);
load([datadir, 'Ballenyspectro_15.mat']);

%% 2.2. load Temp and Wind 
% TempWind data format should be: 1st column-time(datenum); 2nd-Temperature; 3rd-Wind 
TNB_TW = load([datadir, 'TempWind_TNB.txt']); % Original Jang Bogo station data are available on request at KPDC(Korea Polar Data Center)
BI_TW = load([datadir, 'TempWind_BI.txt']); %Original data is from ECMWF website (http://www.ecmwf.int/)

%% 2,3. load Sea Ice 
% Original sea-ice concentraqtion data are from the University of Bremen (http://www.iup.uni-bremen.de/seaice/amsr/)
TNB_SI = load([datadir,'SItimeseries_TNB_1419.txt']); %Daily averaged SIC in TNB, same time period with 'TNBSspectro_16_18.mat'
BI_SI = load([datadir,'SItimeseries_BI50_2015.txt']); %Daily averaged SIC in BI, same time period with 'Ballenyspectro_15.mat'
TNB_SI(:,1) = TNB_SI(:,1)+0.5; % daily average -> change time to noon
BI_SI(:,1) = BI_SI(:,1)+0.5;
%sea-ice extent data are through the NSIDC (https://nsidc.org/data/G02135)
RossSIextent = load([datadir,'Ross_extent_15_16.txt']); 
D2margin = load([datadir,'Dist2Margin.txt']); %distance between Balleny mooring and the ice margin

%% 2.4. load PSDMMC 
% DailyPSDmmc data are generated from "4.PSDMMCandDielpattern"
PSDMMC_BI = load([datadir, 'DailyPSDmmc_BI.txt']);
PSDMMC_TNBS = load([datadir, 'DailyPSDmmc_TNBS.txt']);
PSDMMC_TNBN = load([datadir, 'DailyPSDmmc_TNBN.txt']);
PSDMMC_TNBS = PSDMMC_TNBS(1:end-1,:);
PSDMMC_TNBN = PSDMMC_TNBN(1:end-1,:);

%% 3.1. make time-seaice-wind-psp series For TNB
TSWP_TNB(:,1) = tspN'; %1st column is time
% 2nd column: sea ice data
s_idxSI=find(TNB_SI(:,1)==tspN(1));
e_idxSI=find(TNB_SI(:,1)==tspN(end));
TSWP_TNB(:,2) = TNB_SI(s_idxSI:e_idxSI,2); %2nd column : sea ice concentration
clear s_idxSI e_idxSI;
% weather data (3rd:temp, 4th: wind)
for i=1:size(tspN,2)
    w_idx=find(floor(TNB_TW(:,1))==floor(tspN(i)));
    TSWP_TNB(i,3) = nanmean(TNB_TW(w_idx,2)); %3rd column : Temp
    TSWP_TNB(i,4) = nanmean(TNB_TW(w_idx,3)); %4th column : Wind
    clear w_idx;
end

%make ticks
TNBtidx = find(ticks > TSWP_TNB(1,1) & ticks < TSWP_TNB(end,1));
TNBticks = ticks(13:49);
TNBlabel = datestr(ticks, 'yyyy-mmm'); 
TNB3ticks = TNBticks(1:3:end);

%% 3.2. make time-seaice-wind-psp series For Balleny
TSWP_BI(:,1) = tspB'; %1st column is time
% 2nd column: sea ice data
s_idxSI=find(tspB(:)==BI_SI(1,1));
e_idxSI=find(BI_SI(:,1)==tspB(end));
TSWP_BI(:,2) = NaN;
TSWP_BI(s_idxSI:end,2) = BI_SI(1:e_idxSI,2); %2nd column : sea ice concentration
clear s_idxSI e_idxSI;
% weather data (3rd:temp, 4th: wind)
for i=1:size(tspB,2)
    w_idx=find(floor(BI_TW(:,1))==floor(tspB(i)));
    TSWP_BI(i,3) = nanmean(BI_TW(w_idx,2)); %3rd column : Temp
    TSWP_BI(i,4) = nanmean(BI_TW(w_idx,3)); %4th column : Wind
    clear w_idx;
end

%make ticks
BItidx = find(ticks > TSWP_BI(1,1) & ticks < TSWP_BI(end,1));
BIticks = ticks(BItidx);
BI2ticks = BIticks(1:2:end);
BI3ticks = BIticks(1:3:end);

clear BItidx

%SIextent
sd=ceil(tspB(1)-datenum(2015,1,1)); ed=ceil(tspB(end)-datenum(2015,1,1));
RossSIextent = RossSIextent(sd:ed);


%% 3.3 Calculate Band amps

for k=1:size(FB,1)
    TSWP_TNB(:,4+k) = nanmean(10.^(pspN(:,FB(k,1)+1:FB(k,2))./10),2);
    TSWP_TNB(:,8+k) = nanmean(10.^(pspS(:,FB(k,1)+1:FB(k,2))./10),2);
    TSWP_TNB(:,12+k) = nanmean([TSWP_TNB(:,4+k) TSWP_TNB(:,8+k)],2);
    TSWP_TNB(:,4+k) = 10*log10(TSWP_TNB(:,4+k));
    TSWP_TNB(:,8+k) = 10*log10(TSWP_TNB(:,8+k));
    TSWP_TNB(:,12+k) = 10*log10(TSWP_TNB(:,12+k));
    TSWP_BI(:,4+k) = nanmean(10.^(pspB(:,FB(k,1)+1:FB(k,2))./10),2);
    TSWP_BI(:,4+k) = 10*log10(TSWP_BI(:,4+k));
    
end

MmeanTNB= movmean(TSWP_TNB(:,13:15),10,1);
MmeanBI= movmean(TSWP_BI(:,5:7),10,1);
save('Time_SI_TW_bandpsp_TNBNS.txt', 'TSWP_TNB','-ascii', '-tabs');
save('Time_SI_TW_bandpsp_BI.txt', 'TSWP_BI','-ascii', '-tabs');




%% 4 Band-PSDMMC-wind in 1 plot for TNB (Fig.5 in Yun et al., 2021)

subplot(3,1,1)
%p1=plot(TSWP_TNB(:,1),TSWP_TNB(:,16),'-k','LineWidth',1.5); hold on
p2=plot(TSWP_TNB(:,1),TSWP_TNB(:,13),'-r','LineWidth',0.8); hold on
p3=plot(TSWP_TNB(:,1),TSWP_TNB(:,14),'-b','LineWidth',0.8); hold on
p4=plot(TSWP_TNB(:,1),TSWP_TNB(:,15),'-','Color',[0 0.7 0.3],'LineWidth',0.8); hold on
p5=plot(TSWP_TNB(:,1),MmeanTNB(:,1),'-r','LineWidth',4); hold on
p6=plot(TSWP_TNB(:,1),MmeanTNB(:,2),'-b','LineWidth',4); hold on
p7=plot(TSWP_TNB(:,1),MmeanTNB(:,3),'Color',[0 0.7 0.3],'LineWidth',4); hold on

p2.Color(4) = 0.8;
p3.Color(4) = 0.7;
p4.Color(4) = 0.8;
p5.Color(4) = 0.3;
p6.Color(4) = 0.23;
p7.Color(4) = 0.3;

%legend('15-30Hz', '50-65Hz','300-350Hz','Location','southeast');
columnlegend(3, {'15-30Hz', '50-65Hz','300-350Hz'},'location','northwest')
%legend('boxon');
%ylim([min([TSWP_TNB(:,8+k);TSWP_TNB(:,4+k)]) max([TSWP_TNB(:,8+k);TSWP_TNB(:,4+k)])]);
ylim([65 105]);
ax=gca;
ax.XLim = [TSWP_TNB(1,1) TSWP_TNB(end,1)];
ax.XTick = TNBticks;
labelstr = datestr(TNBticks, 'mmm');
for i = 2:2:36
    labelstr(i,:)='   ';
end
ax.XTickLabel = labelstr;
ax.XTickLabelRotation = 45;
%set(gca,'LineWidth',2,'Tickdir','out')
%ax.XTickLabel = datestr(TNB3ticks, 'yyyy-mmm');
%ax.XTickLabelRotation =45;
set(gca,'LineWidth',2,'Tickdir','out')
set(gca,'fontsize',13)
ax.YLabel.String = 'dB re 1 \muPa^{2}/Hz';
title(['(A) TNB Ambient sound levels'],'fontsize',19)
grid on    

subplot(3,1,2)
plot(PSDMMC_TNBS(:,1), PSDMMC_TNBS(:,2),'m-',PSDMMC_TNBS(:,1), PSDMMC_TNBS(:,3),'g-','LineWidth',1);
hold on
plot(PSDMMC_TNBN(:,1), PSDMMC_TNBN(:,2),'-','Color',[0.6 0.1 0.1],'LineWidth',1);
plot(PSDMMC_TNBN(:,1), PSDMMC_TNBN(:,3),'-','Color',[0 0.6 0.5],'LineWidth',1);
lgd=legend('TNBS','TNBS',...
    'TNBN  Antarctic blue whale [25-28 Hz]','TNBN  Leopard seal [310-360 Hz]',...
    'Location','northwest', 'FontSize',10);
lgd.NumColumns = 2;
ylim([65 105]);
ax=gca;
ax.XLim = [PSDMMC_TNBS(1,1) PSDMMC_TNBS(end,1)];
ax.XTick = TNBticks;
ax.XTickLabel = labelstr;
ax.XTickLabelRotation = 45;
set(gca,'LineWidth',2,'Tickdir','in')
set(gca,'fontsize',13)
ylabel({'PSD_{MMC}', '[dB re 1 \muPa^{2}/Hz]'}, 'fontsize',13);
title('(B) Marine mammal contribution PSD', 'fontsize',19);
grid on 


subplot(3,1,3)
yyaxis left
plot(TSWP_TNB(:,1),TSWP_TNB(:,2),'-','Color',[0 0 0.7],'LineWidth',1.5)
ylim([-5 105]);
ylabel(['SIC (%)'],'fontsize',7,'Color',[0 0 0.7]);
yyaxis right
plot(TSWP_TNB(:,1),TSWP_TNB(:,4),'-','Color',[0 0.6 0.4],'LineWidth',1.5);
ylim([0 25]);
%legend('SIC (%)', 'Wind speed (m/s)','Location','northwest');
ax=gca;
set(ax,'box','off','color','none')
ax.YAxis(1).Color = [0 0 0.7];
ax.YAxis(2).Color = [0 0.6 0.4];
ylabel(['Wind speed (m/s)'],'fontsize',7,'Color',[0 0.6 0.4]);
ax.XLim = [TSWP_TNB(1,1) TSWP_TNB(end,1)];
ax.XTick =TNBticks;
ax.XTickLabel = labelstr;
ax.XTickLabelRotation = 45;
set(gca,'LineWidth',2,'Tickdir','out')
b = axes('Position',get(ax,'Position'),'box','on','xtick',[],'ytick',[],'LineWidth',2);
axes(ax)
% link axes in case of zooming
linkaxes([ax b])
set(gca,'fontsize',13)
title('(C) Sea-ice concentration & wind speed', 'fontsize',19);
grid on

figname =['TNB_bands_SIWind_in1.tiff']; 
set(gcf,'PaperPosition',[0,0,23,23]);
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'TNB_bands_SIWind_in1.jpg');
%saveas(gcf, 'TNB_bands_SIWind', 'epsc');
close all;




%% 5 Band-PSDMMC-wind in 1 plot for BI (Fig.4 in Yun et al., 2021)


subplot(3,1,1)
%p1=plot(TSWP_BI(:,1),TSWP_BI(:,8),'-k','LineWidth',1.5); hold on
p2=plot(TSWP_BI(:,1),TSWP_BI(:,5),'-r','LineWidth',0.8); hold on
p3=plot(TSWP_BI(:,1),TSWP_BI(:,6),'-b','LineWidth',0.8); hold on
p4=plot(TSWP_BI(:,1),TSWP_BI(:,7),'-','Color',[0 0.7 0.3],'LineWidth',0.8); hold on
p5=plot(TSWP_BI(:,1),MmeanBI(:,1),'-r','LineWidth',4); hold on
p6=plot(TSWP_BI(:,1),MmeanBI(:,2),'-b','LineWidth',4); hold on
p7=plot(TSWP_BI(:,1),MmeanBI(:,3),'Color',[0 0.7 0.3],'LineWidth',4); hold on

p2.Color(4) = 0.8;
p3.Color(4) = 0.7;
p4.Color(4) = 0.8;
p5.Color(4) = 0.3;
p6.Color(4) = 0.23;
p7.Color(4) = 0.3;


%legend ('15-30Hz', '50-65Hz','300-350Hz','Location','north');
columnlegend(3, {'15-30Hz', '50-65Hz','300-350Hz'},'location','north');
%legend('boxon');

%ylim([min([TSWP_TNB(:,8+k);TSWP_TNB(:,4+k)]) max([TSWP_TNB(:,8+k);TSWP_TNB(:,4+k)])]);
ylim([60 105]);
ax=gca;
ax.XLim = [TSWP_BI(1,1) TSWP_BI(end,1)];
ax.XTick = BIticks;
ax.XTickLabel = datestr(BIticks, 'mmm');
ax.XTickLabelRotation = 45;
%ax.XTickLabel = datestr(TNB3ticks, 'yyyy-mmm');
%ax.XTickLabelRotation =45;
set(gca,'LineWidth',2,'Tickdir','out')
set(gca,'fontsize',13)
ax.YLabel.String = 'dB re 1 \muPa^{2}/Hz';
title('(A) BI Ambient sound levels','fontsize',19)
grid on    

subplot(3,1,2)
plot(PSDMMC_BI(:,1), PSDMMC_BI(:,2),'r-','LineWidth',1);
hold on
plot(PSDMMC_BI(:,1), PSDMMC_BI(:,3),'-', 'Color', [0.5 0.5 0], 'LineWidth',1);
plot(PSDMMC_BI(:,1), PSDMMC_BI(:,4),'g-', 'LineWidth',1);
lgd=legend('Antarctic blue whale [25-28 Hz]', 'Antarctic minke whale (Feb-Sep) [103-211 Hz]',...
    'Leopard seal (Oct-Jan) [310-360 Hz]','Location','best', 'FontSize',10);
%lgd.NumColumns = 2;
ylim([65 115]);
ax=gca;
ax.XLim = [PSDMMC_BI(1,1) PSDMMC_BI(end,1))];
ax.XTick = BIticks;
ax.XTickLabel = datestr(BIticks, 'mmm');
ax.XTickLabelRotation = 45;
set(gca,'LineWidth',2,'Tickdir','in')
set(gca,'fontsize',13)
ylabel({'PSD_{MMC}', '[dB re 1 \muPa^{2}/Hz]'}, 'fontsize',13);
title('(B) Marine mammal contribution PSD', 'fontsize',19);
grid on 

subplot(3,1,3)
yyaxis left
plot(TSWP_BI(:,1),TSWP_BI(:,2),'-','Color',[0 0 0.7],'LineWidth',1.5)
ylim([-5 105]);
ylabel(['SIC (%)'],'fontsize',7,'Color',[0 0 0.7]);
yyaxis right
plot(TSWP_BI(:,1),TSWP_BI(:,4),'-','Color',[0 0.6 0.4],'LineWidth',1.5);
ylim([0 20]);
ax=gca;
set(ax,'box','off','color','none')
ax.YAxis(1).Color = [0 0 0.7];
ax.YAxis(2).Color = [0 0.6 0.4];
ylabel(['Wind speed (m/s)'],'fontsize',7,'Color',[0 0.6 0.4]);
ax.XLim = [TSWP_BI(1,1) TSWP_BI(end,1)];
ax.XTick =BIticks;
ax.XTickLabel = datestr(BIticks, 'mmm');
ax.XTickLabelRotation = 45;
set(gca,'LineWidth',2,'Tickdir','out')
b = axes('Position',get(ax,'Position'),'box','on','xtick',[],'ytick',[],'LineWidth',2);
axes(ax)
% link axes in case of zooming
linkaxes([ax b])
set(gca,'fontsize',13)
title('(C) Sea-ice concentration & wind speed', 'fontsize',19);
grid on

figname =['BI_bands_SIWind_in1.tiff']; 
set(gcf,'PaperPosition',[0,0,23,23]);
print(gcf,'-r300','-dtiff',figname);
saveas(gcf, 'BI_bands_SIWind_in1.jpg');
%saveas(gcf, 'BI_bands_SIWind', 'epsc');
close all;





%% 6.1. Cumulative days sea-ice conc>80% last 100 days
SIcrt = 80; %sea-ice criteria

for i=1:size(TSWP_TNB,1)
    st = i-99;
    if st<=1
        st=1;
    end
    idx = find(TSWP_TNB(st:i,2)> SIcrt);
    TNB_fdays(i) = size(idx,1);
    clear idx
end
TNB_fdays = TNB_fdays';
    
for i=1:size(TSWP_BI,1)
    st = i-99;
    if st<=1
        st=1;
    end
    idx = find(TSWP_BI(st:i,2)> SIcrt);
    BI_fdays(i) = size(idx,1);
    clear idx
end
BI_fdays = BI_fdays';  


MMTNB= datevec(TSWP_TNB(:,1));
MMBI= datevec(TSWP_BI(:,1));
   
%% 6.2 Distance to sea ice margin-PSDMMC colored month plot for BI (Fig.S6)

HYDloc = [-65.671875 165.204705];
idx = find(D2margin(:,2)<HYDloc(1));
D2margin(idx,1)=0;
clear idx

monthlydist = D2margin((MMBI(:,1)-2015)*12+MMBI(:,2),1);

sicmap = hsv(16);
sicmap = [sicmap(1:5,:);sicmap(8,:);sicmap(10:15,:)] ;
sicmap = sicmap(2:end,:);
%sicmap = colormap(flipud(cool));
%sicmap = sicmap(4:end-4,:);

    nanmx = ~isnan(BI_fdays).*~isnan(PSDMMC_BI(:,2));
    idx = find(nanmx==1);
    %regression
    [p,S]  =  polyfit(BI_fdays(idx),PSDMMC_BI(idx,2),1);
    %make fitting line
    
    %fitting results for save file
    fitSI_PSDMMC(1:2) = p; %1:slope 2:intercept 
    fitSI_PSDMMC(3) = S.df; %3: degree of freedom
    fitSI_PSDMMC(4) = S.normr; %4 norm of the residuals
    % cross-correlation
    ccf = corrcoef(BI_fdays, PSDMMC_BI(:,2),'rows','complete');
    fitSI_PSDMMC(5) = ccf(1,2); %5 pearson coefficient of the residuals    

    figure(1)
    scatter(BI_fdays,PSDMMC_BI(:,2),[],monthlydist,'filled','o');
    colormap(sicmap); caxis([0 500]);
    hold on
    %plot(BI_fdays(idx),polyval(p,BI_fdays(idx)),'-k','LineWidth',1.5);
    clear idx nanmx
    set(gca,'LineWidth',1.5)
    xlim([-3 103]);
    xlabel(['Number of days SIC > 80% in last 100 days'],'fontsize',17);
    ylabel(['PSD_{MMC} (dB re 1 \muPa^{2}/Hz)'],'fontsize',17);
   
    colorbar('Ticks',[0:50:500]);
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15);
    cbar_handle.Label.String = 'Distance to ice margin (km)';
      title(['Balleny Island Ant. blue whale'],'fontsize',19);
    figname =['BI_SIfdays_Dist_PSDMMC.tiff']; 
    set(gcf,'PaperPosition',[0,0,15.24,10.16]);
    print(gcf,'-r300','-dtiff',figname);
    jpgname = ['BI_SIfdays_Dist_PSDMMC.jpg'];
    saveas(gcf, jpgname);
    saveas(gcf, jpgname(1:end-4),'epsc');
    close all


%save('BI_SIfdays_PSP_fitting.txt.','fitSI_PSP','-ascii','-tabs');
clear fitSI_PSP;
   


%% 7. Plot monthly-PSD with seaice concentration by color (Fig.8)

%changetime to n.x month
Mdays = [31 28 31 30 31 30 31 31 30 31 30 31];
for i=1:size(MMTNB,1)
    if MMTNB(i,1)==2016 & MMTNB(i,2)==2
        MMTNB(i,7) = MMTNB(i,2) + (MMTNB(i,3)-1)./29;
    else
        MMTNB(i,7) = MMTNB(i,2) + (MMTNB(i,3)-1)./Mdays(MMTNB(i,2));
    end
end

for i=1:size(MMBI,1)
    if MMBI(i,1)==2016 & MMBI(i,2)==2
        MMBI(i,7) = MMBI(i,2) + (MMBI(i,3)-1)./29;
    else
        MMBI(i,7) = MMBI(i,2) + (MMBI(i,3)-1)./Mdays(MMBI(i,2));
    end
end
sicmap = colormap('parula');
sicmap = sicmap(1:end-4,:);
%for TNB
k=2;
    figure(1)
    scatter(MMTNB(:,7),TSWP_TNB(:,4+k),[],TSWP_TNB(:,2),'filled','o');
    hold on
    scatter(MMTNB(:,7),TSWP_TNB(:,8+k),[],TSWP_TNB(:,2),'filled','o');
    colormap(sicmap); caxis([0 100]);
    set(gca,'LineWidth',1.5)
    xlim([0.9 13.1]);
    set(gca,'XTick',[1:1:12],'XTickLabel',...
    {'Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'});
    xlabel(['Month'],'fontsize',17);
    ylabel(['Sound Level (dB re 1 \muPa^{2}/Hz)'],'fontsize',17);
    colorbar('Ticks',[0:10:100]);
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15);
    cbar_handle.Label.String = 'sea-ice concentration (%)';
    text(0.4, 0.95,[num2str(FB(k,1)) '-' num2str(FB(k,2)) ' Hz'],...
        'FontSize',22,'Units', 'normalized');
    figname =['TNB_monthly_PSD_' num2str(FB(k,1)) '_' num2str(FB(k,2)) '.tiff']; 
    set(gcf,'PaperPosition',[0,0,15.24,10.16]);
    print(gcf,'-r200','-dtiff',figname);
    jpgname = ['TNB_monthly_PSD_' num2str(FB(k,1)) '_' num2str(FB(k,2)) '.jpg'];
    saveas(gcf, jpgname);
    saveas(gcf, jpgname(1:end-4),'epsc');
    close all

TNB_MMCname = {'Ant. blue whale', 'leopard seal'};
for k=1:2;
    figure(1)
    scatter(MMTNB(:,7),PSDMMC_TNBS(:,k+1),[],TSWP_TNB(:,2),'filled','o');
    hold on
    scatter(MMTNB(:,7),PSDMMC_TNBN(:,k+1),[],TSWP_TNB(:,2),'filled','o');
    colormap(sicmap); caxis([0 100]);
    set(gca,'LineWidth',1.5)
    xlim([0.9 13.1]);
    set(gca,'XTick',[1:1:12],'XTickLabel',...
    {'Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'});
    xlabel(['Month'],'fontsize',17);
    ylabel(['PSD_{MMC} (dB re 1 \muPa^{2}/Hz)'],'fontsize',17);
    colorbar('Ticks',[0:10:100]);
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15);
    cbar_handle.Label.String = 'sea-ice concentration (%)';
    text(0.4, 0.95,TNB_MMCname{k},...
        'FontSize',22,'Units', 'normalized');
    figname =['TNB_monthly_PSDMMC_' num2str(k) '.tiff']; 
    set(gcf,'PaperPosition',[0,0,15.24,10.16]);
    print(gcf,'-r200','-dtiff',figname);
    jpgname = ['TNB_monthly_PSDMMC_' num2str(k) '.jpg'];
    saveas(gcf, jpgname);
    saveas(gcf, jpgname(1:end-4),'epsc');
    close all
end
    

%For BI
k=2;
    figure(1)
    scatter(MMBI(:,7),TSWP_BI(:,4+k),[],TSWP_BI(:,2),'filled','o');
    colormap(sicmap); caxis([0 100]);
    set(gca,'LineWidth',1.5)
    xlim([0.9 13.1]);
    set(gca,'XTick',[1:1:12],'XTickLabel',...
    {'Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'});
    xlabel(['Month'],'fontsize',17);
    ylabel(['Sound Level (dB re 1 \muPa^{2}/Hz)'],'fontsize',17);
    colorbar('Ticks',[0:10:100]);
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15);
    cbar_handle.Label.String = 'sea-ice concentration (%)';
    text(0.4, 0.95,[num2str(FB(k,1)) '-' num2str(FB(k,2)) ' Hz'],...
        'FontSize',22,'Units', 'normalized');
    figname =['BI_monthly_PSD_' num2str(FB(k,1)) '_' num2str(FB(k,2)) '.tiff']; 
    set(gcf,'PaperPosition',[0,0,15.24,10.16]);
    print(gcf,'-r200','-dtiff',figname);
    jpgname = ['BI_monthly_PSD_' num2str(FB(k,1)) '_' num2str(FB(k,2)) '.jpg'];
    saveas(gcf, jpgname);
    saveas(gcf, jpgname(1:end-4),'epsc');
    close all
    
BI_MMCname = {'Ant. blue whale', 'Ant. minke whale','leopard seal'};
for k=1:3
    figure(1)
    scatter(MMBI(:,7),PSDMMC_BI(:,k+1),[],TSWP_BI(:,2),'filled','o');
    colormap(sicmap); caxis([0 100]);
    set(gca,'LineWidth',1.5)
    xlim([0.9 13.1]);
    set(gca,'XTick',[1:1:12],'XTickLabel',...
    {'Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'});
    xlabel(['Month'],'fontsize',17);
    ylabel(['PSD_{MMC} (dB re 1 \muPa^{2}/Hz)'],'fontsize',17);
    colorbar('Ticks',[0:10:100]);
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15);
    cbar_handle.Label.String = 'sea-ice concentration (%)';
    text(0.4, 0.95,BI_MMCname{k},...
        'FontSize',22,'Units', 'normalized');
    figname =['BI_monthly_PSDMMC_' num2str(k) '.tiff']; 
    set(gcf,'PaperPosition',[0,0,15.24,10.16]);
    print(gcf,'-r200','-dtiff',figname);
    jpgname = ['BI_monthly_PSDMMC_' num2str(k) '.jpg'];
    saveas(gcf, jpgname);
    saveas(gcf, jpgname(1:end-4),'epsc');
    close all
end





%% Wind-PSD plot for TNB & BI (Fig.9)
%for TNB
WdWd = [TSWP_TNB(:,4);TSWP_TNB(:,4)];
SISI = [TSWP_TNB(:,2);TSWP_TNB(:,2)];
for k=1:size(FB,1)
    NSpsp = [TSWP_TNB(:,4+k);TSWP_TNB(:,8+k)];
    nanmx = ~isnan(SISI).*~isnan(NSpsp).*~isnan(WdWd);
    idx = find(nanmx==1);
    
    iup80 = find(SISI>=80 & isnan(WdWd)==0 & isnan(NSpsp)==0);
    idn80 = find(SISI<80 & isnan(WdWd)==0 & isnan(NSpsp)==0);
    
    
    %regression
    [p,S]  =  polyfit(WdWd(idx),NSpsp(idx),1);
    %make fitting line
    
    %fitting results for save file
    fitWd_PSP(k,1:2) = p; %1:slope 2:intercept 
    fitWd_PSP(k,3) = S.df; %3: degree of freedom
    fitWd_PSP(k,4) = S.normr; %4 norm of the residuals
    
    %calc corr
    ccf = corrcoef(WdWd,NSpsp,'rows','complete');
    fitWd_PSP(k,5) = ccf(1,2); %4 norm of the residuals

    %regression for up80
    [pUP,SUP]  =  polyfit(WdWd(iup80),NSpsp(iup80),1);
    %make fitting line
    
    %fitting results for save file
    fitWdup80_PSP(k,1:2) = pUP; %1:slope 2:intercept 
    fitWdup80_PSP(k,3) = SUP.df; %3: degree of freedom
    fitWdup80_PSP(k,4) = SUP.normr; %4 norm of the residuals
    
    %calc corr
    ccf = corrcoef(WdWd(iup80),NSpsp(iup80),'rows','complete');
    fitWdup80_PSP(k,5) = ccf(1,2); %4 norm of the residuals

    %regression for down80
    [pDN,SDN]  =  polyfit(WdWd(idn80),NSpsp(idn80),1);
    %make fitting line
    
    %fitting results for save file
    fitWddn80_PSP(k,1:2) = pDN; %1:slope 2:intercept 
    fitWddn80_PSP(k,3) = SDN.df; %3: degree of freedom
    fitWddn80_PSP(k,4) = SDN.normr; %4 norm of the residuals
    
    %calc corr
    ccf = corrcoef(WdWd(idn80),NSpsp(idn80),'rows','complete');
    fitWddn80_PSP(k,5) = ccf(1,2); %4 norm of the residuals
    
    
    figure(1)
    h=scatter(WdWd,NSpsp,[],SISI,'filled','o');
    h.Annotation.LegendInformation.IconDisplayStyle = 'off';
    hold on
    plot(WdWd,polyval(pUP,WdWd),'-','Color',[0.8 0.4 0],'LineWidth',1.5);
    plot(WdWd,polyval(pDN,WdWd),'-','Color',[0.3 0.2 1],'LineWidth',1.5);
    legend(['sea-ice concentration > 80%,  Slope: ' num2str(pUP(1),'%.2f')]...
        , ['sea-ice concentration < 80%,  Slope: ' num2str(pDN(1),'%.2f')]...
        ,'Location','southeast');
    set(gca,'LineWidth',1.5)
    xlim([0 20]); 
    xlabel(['Wind speed (m/s)'],'fontsize',17);
    ylabel(['Sound Level (dB re 1 \muPa^{2}/Hz)'],'fontsize',17);
    colormap(sicmap); caxis([0 100]);
    colorbar('Ticks',[0:10:100]);
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15);
    cbar_handle.Label.String = 'sea-ice concentration (%)';
    text(0.4, 0.95,[num2str(FB(k,1)) '-' num2str(FB(k,2)) ' Hz'],...
        'FontSize',22,'Units', 'normalized');
    figname =['TNB_Wd_cSIC_PSD_' num2str(FB(k,1)) '_' num2str(FB(k,2)) '.tiff']; 
    set(gcf,'PaperPosition',[0,0,15.24,10.16]);
    print(gcf,'-r200','-dtiff',figname);
    jpgname = ['TNB_Wd_cSIC_PSD_' num2str(FB(k,1)) '_' num2str(FB(k,2)) '.jpg'];
    saveas(gcf, jpgname);
    close all
    
    clear idx nanmx iup80 idn80
    
end


save('TNB_Wd_PSP_fitting.txt.','fitWd_PSP','-ascii','-tabs');
save('TNB_Wd_UP80_PSP_fitting.txt.','fitWdup80_PSP','-ascii','-tabs');
save('TNB_Wd_DN80_PSP_fitting.txt.','fitWddn80_PSP','-ascii','-tabs');
clear fitWd_PSP fitWddn80_PSP fitWdup80_PSP;


%for BI
for k=1:size(FB,1)
    nanmx = ~isnan(TSWP_BI(:,4+k)).*~isnan(TSWP_BI(:,2)).*~isnan(TSWP_BI(:,4));
    idx = find(nanmx==1);
    
    iup80 = find(TSWP_BI(:,2)>=80 & isnan(TSWP_BI(:,4))==0 & isnan(TSWP_BI(:,4+k))==0);
    idn80 = find(TSWP_BI(:,2)<80 & isnan(TSWP_BI(:,4))==0 & isnan(TSWP_BI(:,4+k))==0);
    
    
       %regression
    [p,S]  =  polyfit(TSWP_BI(idx,4),TSWP_BI(idx,4+k),1);
    %make fitting line
    
    %fitting results for save file
    fitWd_PSP(k,1:2) = p; %1:slope 2:intercept 
    fitWd_PSP(k,3) = S.df; %3: degree of freedom
    fitWd_PSP(k,4) = S.normr; %4 norm of the residuals
    
    %calc corr
    ccf = corrcoef(TSWP_BI(:,4),TSWP_BI(:,4+k),'rows','complete');
    fitWd_PSP(k,5) = ccf(1,2); %4 norm of the residuals
    
    
    %regression for up80
    [pUP,SUP]  =  polyfit(TSWP_BI(iup80,4),TSWP_BI(iup80,4+k),1);
    %make fitting line
    
    %fitting results for save file
    fitWdup80_PSP(k,1:2) = pUP; %1:slope 2:intercept 
    fitWdup80_PSP(k,3) = SUP.df; %3: degree of freedom
    fitWdup80_PSP(k,4) = SUP.normr; %4 norm of the residuals
    
    %calc corr
    ccf = corrcoef(TSWP_BI(iup80,4),TSWP_BI(iup80,4+k),'rows','complete');
    fitWdup80_PSP(k,5) = ccf(1,2); %4 norm of the residuals

    %regression for down80
    [pDN,SDN]  =  polyfit(TSWP_BI(idn80,4),TSWP_BI(idn80,4+k),1);
    %make fitting line
    
    %fitting results for save file
    fitWddn80_PSP(k,1:2) = pDN; %1:slope 2:intercept 
    fitWddn80_PSP(k,3) = SDN.df; %3: degree of freedom
    fitWddn80_PSP(k,4) = SDN.normr; %4 norm of the residuals
    
    %calc corr
    ccf = corrcoef(TSWP_BI(idn80,4),TSWP_BI(idn80,4+k),'rows','complete');
    fitWddn80_PSP(k,5) = ccf(1,2); %4 norm of the residuals
    
    
    figure(1)
    h=scatter(TSWP_BI(:,4),TSWP_BI(:,4+k),[],TSWP_BI(:,2),'filled','o');
    h.Annotation.LegendInformation.IconDisplayStyle = 'off';
    hold on
    plot(TSWP_BI(:,4),polyval(pUP,TSWP_BI(:,4)),'-','Color',[0.8 0.4 0],'LineWidth',1.5);
    plot(TSWP_BI(:,4),polyval(pDN,TSWP_BI(:,4)),'-','Color',[0.3 0.2 1],'LineWidth',1.5);
    legend(['sea-ice concentration > 80%,  Slope: ' num2str(pUP(1),'%.2f')]...
        , ['sea-ice concentration < 80%,  Slope: ' num2str(pDN(1),'%.2f')]...
        ,'Location','southeast');
    set(gca,'LineWidth',1.5)
    xlim([0 20]);
    xlabel(['Wind speed (m/s)'],'fontsize',17);
    ylabel(['Sound Level (dB re 1 \muPa^{2}/Hz)'],'fontsize',17);
    
    colormap(sicmap); caxis([0 100]);
    colorbar('Ticks',[0:10:100]);
    cbar_handle = findobj(gcf,'tag','Colorbar');
    set(cbar_handle,'FontSize',15);
    cbar_handle.Label.String = 'sea-ice concentration (%)';
    text(0.4, 0.95,[num2str(FB(k,1)) '-' num2str(FB(k,2)) ' Hz'],...
        'FontSize',22,'Units', 'normalized');
    figname =['BI_Wd_cSIC_PSD_' num2str(FB(k,1)) '_' num2str(FB(k,2)) '.tiff']; 
    set(gcf,'PaperPosition',[0,0,15.24,10.16]);
    print(gcf,'-r200','-dtiff',figname);
    jpgname = ['BI_Wd_cSIC_PSD_' num2str(FB(k,1)) '_' num2str(FB(k,2)) '.jpg'];
    saveas(gcf, jpgname);
    close all
    
    clear idx nanmx iup80 idn80
end

    
save('BI_Wd_PSP_fitting.txt.','fitWd_PSP','-ascii','-tabs');
save('BI_Wd_UP80_PSP_fitting.txt.','fitWdup80_PSP','-ascii','-tabs');
save('BI_Wd_DN80_PSP_fitting.txt.','fitWddn80_PSP','-ascii','-tabs');

